==> bit-bin-13.0.4.tgz: package/e2e/flows/delete-files.e2e.2.js <==
import { expect } from 'chai';
import Helper from '../e2e-helper';

describe('delete files from a component', function () {
  this.timeout(0);
  const helper = new Helper();
  after(() => {
    helper.destroyEnv();
  });
  describe('after adding it', () => {
    let statusOutput;
    before(() => {
      helper.reInitLocalScope();
      helper.createComponentBarFoo();
      helper.createFile('bar', 'baz.js');
      helper.addComponent('bar -i bar/foo -m bar/foo.js');
      helper.deleteFile('bar/baz.js');
      statusOutput = helper.runCmd('bit status');
    });
    it('bit status should not throw an error and should show it as a new component', () => {
      expect(statusOutput.includes('new components')).to.be.true;
      expect(statusOutput.includes('bar/foo')).to.be.true;
    });
  });
  describe('when committing it', () => {
    before(() => {
      helper.reInitLocalScope();
      helper.createComponentBarFoo();
      helper.createFile('bar', 'baz.js');
      helper.addComponent('bar -i bar/foo -m bar/foo.js');
      helper.deleteFile('bar/baz.js');
      helper.commitComponent('bar/foo');
    });
    it('should delete the file from bit.map', () => {
      const bitMap = helper.readBitMap();
      expect(bitMap['bar/foo@0.0.1'].files.length).to.equal(1);
    });
  });
  describe('commit and then delete a file', () => {
    before(() => {
      helper.reInitLocalScope();
      helper.createComponentBarFoo();
      helper.createFile('bar', 'baz.js');
      helper.addComponent('bar -i bar/foo -m bar/foo.js');
      helper.commitComponent('bar/foo');
      helper.deleteFile('bar/baz.js');
    });
    it('bit status should show the component as modified', () => {
      const output = helper.runCmd('bit status');
      expect(output.includes('modified components')).to.be.true;
      expect(output.includes('bar/foo')).to.be.true;
    });
  });
  describe('adding a file, committing it, deleting it and then committing again', () => {
    before(() => {
      helper.reInitLocalScope();
      helper.createComponentBarFoo();
      helper.createFile('bar', 'baz.js');
      helper.addComponent('bar -i bar/foo -m bar/foo.js');
      helper.commitComponent('bar/foo');
      helper.deleteFile('bar/baz.js');
      helper.commitComponent('bar/foo');
    });
    it('should delete the file from bit.map', () => {
      const bitMap = helper.readBitMap();
      expect(bitMap['bar/foo@0.0.2'].files.length).to.equal(1);
    });
    it('should not show the deleted file in bit show command', () => {
      const output = helper.showComponent('bar/foo');
      expect(output).to.have.string('bar/foo.js');
      expect(output).not.to.have.string('bar/baz.js');
    });
  });
});

==> bit-bin-14.1.1.tgz: package/e2e/flows/delete-files.e2e.2.js <==
import { expect } from 'chai';
import Helper from '../e2e-helper';

describe('delete files from a component', function () {
  this.timeout(0);
  const helper = new Helper();
  after(() => {
    helper.destroyEnv();
  });
  describe('after adding it', () => {
    let statusOutput;
    before(() => {
      helper.reInitLocalScope();
      helper.createComponentBarFoo();
      helper.createFile('bar', 'baz.js');
      helper.addComponent('bar -i bar/foo -m bar/foo.js');
      helper.deleteFile('bar/baz.js');
      statusOutput = helper.runCmd('bit status');
    });
    it('bit status should not throw an error and should show it as a new component', () => {
      expect(statusOutput.includes('new components')).to.be.true;
      expect(statusOutput.includes('bar/foo')).to.be.true;
    });
  });
  describe('when tagging it', () => {
    before(() => {
      helper.reInitLocalScope();
      helper.createComponentBarFoo();
      helper.createFile('bar', 'baz.js');
      helper.addComponent('bar -i bar/foo -m bar/foo.js');
      helper.deleteFile('bar/baz.js');
      helper.tagComponent('bar/foo');
    });
    it('should delete the file from bit.map', () => {
      const bitMap = helper.readBitMap();
      expect(bitMap['bar/foo@0.0.1'].files.length).to.equal(1);
    });
  });
  describe('tag and then delete a file', () => {
    before(() => {
      helper.reInitLocalScope();
      helper.createComponentBarFoo();
      helper.createFile('bar', 'baz.js');
      helper.addComponent('bar -i bar/foo -m bar/foo.js');
      helper.tagComponent('bar/foo');
      helper.deleteFile('bar/baz.js');
    });
    it('bit status should show the component as modified', () => {
      const output = helper.runCmd('bit status');
      expect(output.includes('modified components')).to.be.true;
      expect(output.includes('bar/foo')).to.be.true;
    });
  });
  describe('adding a file, tagging it, deleting it and then tagging again', () => {
    before(() => {
      helper.reInitLocalScope();
      helper.createComponentBarFoo();
      helper.createFile('bar', 'baz.js');
      helper.addComponent('bar -i bar/foo -m bar/foo.js');
      helper.tagComponent('bar/foo');
      helper.deleteFile('bar/baz.js');
      helper.tagComponent('bar/foo');
    });
    it('should delete the file from bit.map', () => {
      const bitMap = helper.readBitMap();
      expect(bitMap['bar/foo@0.0.2'].files.length).to.equal(1);
    });
    it('should not show the deleted file in bit show command', () => {
      const output = helper.showComponent('bar/foo');
      expect(output).to.have.string('bar/foo.js');
      expect(output).not.to.have.string('bar/baz.js');
    });
  });
});
